@@ -6,7 +6,7 @@ from django.urls import reverse
 from django.db.models.fields import CharField
 from django.forms.widgets import Input
 from django.template.loader import render_to_string
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.contrib.admin.options import FORMFIELD_FOR_DBFIELD_DEFAULTS
 
 from filebrowser.base import FileObject
